@@ -26,20 +26,23 @@ import bluesky.preprocessors as bpp
 import numpy as np
 import pyFAI
 import yaml
-from bluesky.callbacks import LiveTable
 from xpdconf.conf import XPD_SHUTTER_CONF
 
 from .glbl import glbl
 from .tools import regularize_dict_key
 from .validated_dict import ValidatedDictLike
 from .xpdacq_conf import xpd_configuration
-from .yamldict import YamlDict, YamlChainMap
+from .yamldict import YamlChainMap, YamlDict
 
 # This is used to map plan names (strings in the YAML file) to actual
 # plan functions in Python.
 _PLAN_REGISTRY = {}
 
 
+class PlanError(Exception):
+    pass
+
+
 def register_plan(plan_name, plan_func, overwrite=False):
     """
     Map between a plan_name (string) and a plan_func (generator function).
@@ -85,12 +88,19 @@ def _summarize(plan):
 def configure_area_det(det, exposure, acq_time):
     """Configure exposure time of a detector in continuous acquisition mode"""
     _check_mini_expo(exposure, acq_time)
-    yield from bps.mv(det.cam.acquire_time, acq_time)
-    res = yield from bps.read(det.cam.acquire_time)
-    real_acq_time = res[det.cam.acquire_time.name]["value"] if res else 1
-    if hasattr(det, "images_per_set"):
+    real_acq_time = None
+    # if the detector has a camera and acquire time, set it
+    if hasattr(det, "cam"):
+        if hasattr(det.cam, "acquire_time"):
+            yield from bps.mv(det.cam.acquire_time, acq_time)
+            real_acq_time = (yield from bps.rd(det.cam.acquire_time))
+        else:
+            print("WARNING: `{}.cam` doesn't have `acquire_time` signal.".format(det.name))
+    else:
+        print("WARNING: `{}` doesn't have `cam` component.".format(det.name))
+    if hasattr(det, "images_per_set") and (real_acq_time is not None):
         # compute number of frames
-        num_frame = np.ceil(exposure / real_acq_time)
+        num_frame = int(np.ceil(exposure / real_acq_time))
         yield from bps.mv(det.images_per_set, num_frame)
     else:
         # The dexela detector does not support `images_per_set` so we just
@@ -176,6 +186,12 @@ def close_shutter_stub():
     yield from bps.checkpoint()
 
 
+def xpdacq_per_shot(detectors):
+    yield from open_shutter_stub()
+    yield from bps.trigger_and_read(detectors)
+    yield from close_shutter_stub()
+
+
 def ct(dets, exposure):
     """
     Take one reading from area detector with given exposure time
@@ -220,11 +236,10 @@ def ct(dets, exposure):
         },
     )
     plan = bp.count([area_det], md=_md)
-    plan = bpp.subs_wrapper(plan, LiveTable([]))
     yield from plan
 
 
-def Tramp(dets, exposure, Tstart, Tstop, Tstep, *, per_step=shutter_step):
+def Tramp(dets, exposure, Tstart, Tstop, Tstep, per_step=None):
     """
     Collect data over a range of temperatures
 
@@ -248,17 +263,6 @@ def Tramp(dets, exposure, Tstart, Tstop, Tstep, *, per_step=shutter_step):
         stoping point of temperature sequence.
     Tstep : float
         step size between Tstart and Tstop of this sequence.
-    per_step : callable, optional
-        hook for customizing action at each temperature point.
-        Tramp uses this for opening and closing the shutter at each
-        temperature acquisition.
-
-        Default behavior:
-        `` open shutter - collect data - close shutter ``
-
-        To make shutter always open during the temperature ramp,
-        pass ``None`` to this argument. See ``Notes`` below for more
-        detailed information.
 
     Notes
     -----
@@ -312,14 +316,13 @@ def Tramp(dets, exposure, Tstart, Tstop, Tstep, *, per_step=shutter_step):
         Tstart,
         Tstop,
         Nsteps,
-        per_step=per_step,
         md=_md,
+        per_step=per_step
     )
-    plan = bpp.subs_wrapper(plan, LiveTable([temp_controller]))
     yield from plan
 
 
-def Tlist(dets, exposure, T_list, *, per_step=shutter_step):
+def Tlist(dets, exposure, T_list, per_step=None):
     """
     Collect data over a list of user-specific temperatures
 
@@ -339,17 +342,6 @@ def Tlist(dets, exposure, T_list, *, per_step=shutter_step):
         total time of exposure in seconds
     T_list : list
         a list of temperatures where a scan will be run
-    per_step : callable, optional
-        hook for customizing action at each temperature point.
-        Tramp uses this for opening and closing the shutter at each
-        temperature acquisition.
-
-        Default behavior:
-        `` open shutter - collect data - close shutter ``
-
-        To make shutter always open during the temperature ramp,
-        pass ``None`` to this argument. See ``Notes`` below for more
-        detailed information.
 
     Notes
     -----
@@ -388,13 +380,12 @@ def Tlist(dets, exposure, T_list, *, per_step=shutter_step):
     }
     # pass xpdacq_md to as additional md to bluesky plan
     plan = bp.list_scan(
-        [area_det], T_controller, T_list, per_step=per_step, md=xpdacq_md
+        [area_det], T_controller, T_list, md=xpdacq_md, per_step=per_step
     )
-    plan = bpp.subs_wrapper(plan, LiveTable([T_controller]))
     yield from plan
 
 
-def tseries(dets, exposure, delay, num, auto_shutter=True):
+def tseries(dets, exposure, delay, num, auto_shutter=False):
     """
     time series scan with area detector.
 
@@ -470,7 +461,6 @@ def tseries(dets, exposure, delay, num, auto_shutter=True):
         },
     )
     plan = bp.count([area_det], num, delay, md=_md)
-    plan = bpp.subs_wrapper(plan, LiveTable([]))
 
     def inner_shutter_control(msg):
         if msg.command == "trigger":
@@ -1008,13 +998,6 @@ def count_with_calib(detectors: list, num: int = 1, delay: float = None, *, cali
     delay : iterable or scalar, optional
         Time delay in seconds between successive readings; default is 0.
 
-    per_shot : callable, optional
-        hook for customizing action of inner loop (messages per step)
-        Expected signature ::
-
-           def f(detectors: Iterable[OphydObj]) -> Generator[Msg]:
-               ...
-
     calibration_md :
         The calibration data in a dictionary. If not applied, the function is a normal `bluesky.plans.count`.
 
@@ -1030,9 +1013,13 @@ def count_with_calib(detectors: list, num: int = 1, delay: float = None, *, cali
         md = dict()
     if calibration_md is not None:
         md["calibration_md"] = calibration_md
-    yield from open_shutter_stub()
-    plan = bp.count(detectors, num, delay, md=md)
-    bpp.subs_wrapper(plan, LiveTable(detectors))
+
+    def _per_shot(_detectors):
+        yield from open_shutter_stub()
+        yield from bps.one_shot(_detectors)
+        yield from close_shutter_stub()
+        return
+
+    plan = bp.count(detectors, num, delay, md=md, per_shot=_per_shot)
     sts = yield from plan
-    yield from close_shutter_stub()
     return sts
