@@ -5,7 +5,7 @@ from xpdacq.simulators import WorkSpace
 
 def test_configure_area_det():
     ws = WorkSpace()
-    ws.RE(xbt.configure_area_det(ws.det, 5.0, 0.1))
+    ws.RE(xbt.configure_area_det(ws.det, 5., 0.1))
     assert ws.det.cam.acquire_time.get() == 0.1
     assert ws.det.images_per_set.get() == 50
 
@@ -18,7 +18,9 @@ def test_ct():
     del ws
     xpd_configuration["area_det"] = det
     RE(xbt.ct([det], 0.1))
-    assert db[-1]
+    key = "{}_image".format(det.name)
+    data = list(db[-1].data(key))
+    assert len(data) == 1
 
 
 def test_Tlist():
@@ -30,9 +32,11 @@ def test_Tlist():
     del ws
     xpd_configuration["area_det"] = det
     xpd_configuration["temp_controller"] = eurotherm
-    setpoints = [100.0, 200.0, 300.0]
+    setpoints = [100., 200., 300.]
     RE(xbt.Tlist([det], 0.1, setpoints))
-    assert db[-1]
+    key = eurotherm.name
+    measured = list(db[-1].data(key))
+    assert measured == setpoints
 
 
 def test_Tramp():
@@ -44,5 +48,8 @@ def test_Tramp():
     del ws
     xpd_configuration["area_det"] = det
     xpd_configuration["temp_controller"] = eurotherm
-    RE(xbt.Tramp([det], 0.1, 100.0, 300.0, 100.0))
-    assert db[-1]
+    setpoints = [100., 200., 300.]
+    RE(xbt.Tramp([det], 0.1, 100., 300., 100.))
+    key = eurotherm.name
+    measured = list(db[-1].data(key))
+    assert measured == setpoints
